@@ -1,10 +1,10 @@
 package Text::Template::Simple::Base::Parser;
 use strict;
 use vars qw($VERSION);
-use Text::Template::Simple::Util;
-use Text::Template::Simple::Constants;
+use Text::Template::Simple::Util qw(:all);
+use Text::Template::Simple::Constants qw(:all);
 
-$VERSION = '0.62_07';
+$VERSION = '0.62_08';
 
 # internal code templates
 my %INTERNAL = (
@@ -159,14 +159,14 @@ sub _parse {
 
       else {
          if ( $handler ) {
-            LOG( USER_THANDLER => "$id") if DEBUG;
+            LOG( USER_THANDLER => "$id") if DEBUG();
             $code .= $handler->(
                         $self, $id ,$str, { capture => $w_cap, raw => $w_raw }
                      );
          }
          else {
             LOG( UNKNOWN_TOKEN => "Adding unknown token as RAW: $id($str)")
-               if DEBUG;
+               if DEBUG();
             $code .= $w_raw->($str);
          }
       }
@@ -177,9 +177,9 @@ sub _parse {
 
    fatal(
       'tts.base.parser._parse.unbalanced',
-      abs($inside),
-      ($inside > 0 ? 'opening' : 'closing'),
-      $self->[FILENAME]
+         abs($inside),
+         ($inside > 0 ? 'opening' : 'closing'),
+         $self->[FILENAME]
    ) if $inside;
 
    return $self->_wrapper( $code, $cache_id, $faker, $map_keys );
@@ -355,8 +355,8 @@ Private module.
 
 =head1 DESCRIPTION
 
-This document describes version C<0.62_07> of C<Text::Template::Simple::Base::Parser>
-released on C<5 April 2009>.
+This document describes version C<0.62_08> of C<Text::Template::Simple::Base::Parser>
+released on C<8 April 2009>.
 
 B<WARNING>: This version of the module is part of a
 developer (beta) release of the distribution and it is
