@@ -2,7 +2,7 @@ package Text::Template::Simple::Constants;
 use strict;
 use vars qw($VERSION $OID $DID @ISA @EXPORT @EXPORT_OK %EXPORT_TAGS);
 
-$VERSION = '0.62_07';
+$VERSION = '0.62_08';
 
 # object fields
 BEGIN { $OID = -1 } # init object field id counter
@@ -213,10 +213,7 @@ use constant RESUME_ELSE => qr{
 
 use constant RESUME_LOOP => qr{ (?:next|last|continue|redo) }xms;
 
-use Exporter ();
-
 BEGIN {
-
    @ISA         = qw( Exporter );
 
    %EXPORT_TAGS = (
@@ -349,6 +346,8 @@ BEGIN {
 
 }
 
+BEGIN { require Exporter; }
+
 1;
 
 __END__
@@ -363,8 +362,8 @@ TODO
 
 =head1 DESCRIPTION
 
-This document describes version C<0.62_07> of C<Text::Template::Simple::Constants>
-released on C<5 April 2009>.
+This document describes version C<0.62_08> of C<Text::Template::Simple::Constants>
+released on C<8 April 2009>.
 
 B<WARNING>: This version of the module is part of a
 developer (beta) release of the distribution and it is
